@@ -7,7 +7,7 @@
  
  @section LICENSE
  
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -129,10 +129,7 @@ def get_icon(theme_name):
 
     if theme_name:
         has_icon = QIcon.hasThemeIcon(theme_name)
-        if not has_icon:
-            log.warn('Icon theme {} not found. Will use backup icon.'.format(theme_name))
         fallback_icon, fallback_path = get_default_icon(theme_name)
-        # log.info('Fallback icon path for {} is {}'.format(theme_name, fallback_path))
         if has_icon or fallback_icon:
             return QIcon.fromTheme(theme_name, fallback_icon)
     return None
@@ -196,13 +193,11 @@ def connect_auto_events(window, elem, name):
         func_name = name + "_trigger"
         if hasattr(window, func_name) and callable(getattr(window, func_name)):
             func = getattr(window, func_name)
-            log.info("Binding event {}:{}".format(window.objectName(), func_name))
             elem.triggered.connect(getattr(window, func_name))
     if hasattr(elem, 'click'):
         func_name = name + "_click"
         if hasattr(window, func_name) and callable(getattr(window, func_name)):
             func = getattr(window, func_name)
-            log.info("Binding event {}:{}".format(window.objectName(), func_name))
             elem.clicked.connect(getattr(window, func_name))
 
 
@@ -225,7 +220,6 @@ def init_ui(window):
 
         # Loop through all actions
         for action in window.findChildren(QAction):
-            # log.info('Initializing element: {}'.format(action))
             init_element(window, action)
     except:
         log.info('Failed to initialize an element on {}'.format(window.objectName()))
