@@ -101,7 +101,8 @@ class Export(QDialog):
         self.txtChannels.setVisible(False)
 
         # Set OMP thread disabled flag (for stability)
-        os.environ['OS2_OMP_THREADS'] = "0"
+        openshot.Settings.Instance().WAIT_FOR_VIDEO_PROCESSING_TASK = True
+        openshot.Settings.Instance().HIGH_QUALITY_SCALING = True
 
         # Get the original timeline settings
         width = get_app().window.timeline_sync.timeline.info.width
@@ -111,6 +112,9 @@ class Export(QDialog):
         channels = get_app().window.timeline_sync.timeline.info.channels
         channel_layout = get_app().window.timeline_sync.timeline.info.channel_layout
 
+        # No keyframe rescaling has happened yet (due to differences in FPS)
+        self.keyframes_rescaled = False
+
         # Create new "export" openshot.Timeline object
         self.timeline = openshot.Timeline(width, height, openshot.Fraction(fps.num, fps.den),
                                           sample_rate, channels, channel_layout)
@@ -225,10 +229,11 @@ class Export(QDialog):
         # ********* Simple Project Type **********
         # load the simple project type dropdown
         presets = []
-        for file in os.listdir(info.EXPORT_PRESETS_DIR):
-            xmldoc = xml.parse(os.path.join(info.EXPORT_PRESETS_DIR, file))
-            type = xmldoc.getElementsByTagName("type")
-            presets.append(_(type[0].childNodes[0].data))
+        for preset_path in [info.EXPORT_PRESETS_PATH, info.USER_PRESETS_PATH]:
+            for file in os.listdir(preset_path):
+                xmldoc = xml.parse(os.path.join(preset_path, file))
+                type = xmldoc.getElementsByTagName("type")
+                presets.append(_(type[0].childNodes[0].data))
 
         # Exclude duplicates
         type_index = 0
@@ -349,6 +354,13 @@ class Export(QDialog):
         self.progressExportVideo.setMaximum(self.txtEndFrame.value())
         self.progressExportVideo.setValue(self.txtStartFrame.value())
 
+        # Calculate differences between editing/preview FPS and export FPS
+        current_fps = get_app().project.get(["fps"])
+        current_fps_float = float(current_fps["num"]) / float(current_fps["den"])
+        new_fps_float = float(self.txtFrameRateNum.value()) / float(self.txtFrameRateDen.value())
+        self.export_fps_factor = new_fps_float / current_fps_float
+        self.original_fps_factor = current_fps_float / new_fps_float
+
     def cboSimpleProjectType_index_changed(self, widget, index):
         selected_project = widget.itemData(index)
 
@@ -362,14 +374,15 @@ class Export(QDialog):
 
         # parse the xml files and get targets that match the project type
         project_types = []
-        for file in os.listdir(info.EXPORT_PRESETS_DIR):
-            xmldoc = xml.parse(os.path.join(info.EXPORT_PRESETS_DIR, file))
-            type = xmldoc.getElementsByTagName("type")
+        for preset_path in [info.EXPORT_PRESETS_PATH, info.USER_PRESETS_PATH]:
+            for file in os.listdir(preset_path):
+                xmldoc = xml.parse(os.path.join(preset_path, file))
+                type = xmldoc.getElementsByTagName("type")
 
-            if _(type[0].childNodes[0].data) == selected_project:
-                titles = xmldoc.getElementsByTagName("title")
-                for title in titles:
-                    project_types.append(_(title.childNodes[0].data))
+                if _(type[0].childNodes[0].data) == selected_project:
+                    titles = xmldoc.getElementsByTagName("title")
+                    for title in titles:
+                        project_types.append(_(title.childNodes[0].data))
 
         # Add all targets for selected project type
         preset_index = 0
@@ -441,75 +454,76 @@ class Export(QDialog):
             # parse the xml to return suggested profiles
             profile_index = 0
             all_profiles = False
-            for file in os.listdir(info.EXPORT_PRESETS_DIR):
-                xmldoc = xml.parse(os.path.join(info.EXPORT_PRESETS_DIR, file))
-                title = xmldoc.getElementsByTagName("title")
-                if _(title[0].childNodes[0].data) == selected_target:
-                    profiles = xmldoc.getElementsByTagName("projectprofile")
+            for preset_path in [info.EXPORT_PRESETS_PATH, info.USER_PRESETS_PATH]:
+                for file in os.listdir(preset_path):
+                    xmldoc = xml.parse(os.path.join(preset_path, file))
+                    title = xmldoc.getElementsByTagName("title")
+                    if _(title[0].childNodes[0].data) == selected_target:
+                        profiles = xmldoc.getElementsByTagName("projectprofile")
 
-                    # get the basic profile
-                    all_profiles = False
-                    if profiles:
-                        # if profiles are defined, show them
-                        for profile in profiles:
-                            profiles_list.append(_(profile.childNodes[0].data))
-                    else:
-                        # show all profiles
-                        all_profiles = True
-                        for profile_name in self.profile_names:
-                            profiles_list.append(profile_name)
+                        # get the basic profile
+                        all_profiles = False
+                        if profiles:
+                            # if profiles are defined, show them
+                            for profile in profiles:
+                                profiles_list.append(_(profile.childNodes[0].data))
+                        else:
+                            # show all profiles
+                            all_profiles = True
+                            for profile_name in self.profile_names:
+                                profiles_list.append(profile_name)
 
-                    # get the video bit rate(s)
-                    videobitrate = xmldoc.getElementsByTagName("videobitrate")
-                    for rate in videobitrate:
-                        v_l = rate.attributes["low"].value
-                        v_m = rate.attributes["med"].value
-                        v_h = rate.attributes["high"].value
-                        self.vbr = {_("Low"): v_l, _("Med"): v_m, _("High"): v_h}
+                        # get the video bit rate(s)
+                        videobitrate = xmldoc.getElementsByTagName("videobitrate")
+                        for rate in videobitrate:
+                            v_l = rate.attributes["low"].value
+                            v_m = rate.attributes["med"].value
+                            v_h = rate.attributes["high"].value
+                            self.vbr = {_("Low"): v_l, _("Med"): v_m, _("High"): v_h}
 
-                    # get the audio bit rates
-                    audiobitrate = xmldoc.getElementsByTagName("audiobitrate")
-                    for audiorate in audiobitrate:
-                        a_l = audiorate.attributes["low"].value
-                        a_m = audiorate.attributes["med"].value
-                        a_h = audiorate.attributes["high"].value
-                        self.abr = {_("Low"): a_l, _("Med"): a_m, _("High"): a_h}
+                        # get the audio bit rates
+                        audiobitrate = xmldoc.getElementsByTagName("audiobitrate")
+                        for audiorate in audiobitrate:
+                            a_l = audiorate.attributes["low"].value
+                            a_m = audiorate.attributes["med"].value
+                            a_h = audiorate.attributes["high"].value
+                            self.abr = {_("Low"): a_l, _("Med"): a_m, _("High"): a_h}
 
-                    # get the remaining values
-                    vf = xmldoc.getElementsByTagName("videoformat")
-                    self.txtVideoFormat.setText(vf[0].childNodes[0].data)
-                    vc = xmldoc.getElementsByTagName("videocodec")
-                    self.txtVideoCodec.setText(vc[0].childNodes[0].data)
-                    sr = xmldoc.getElementsByTagName("samplerate")
-                    self.txtSampleRate.setValue(int(sr[0].childNodes[0].data))
-                    c = xmldoc.getElementsByTagName("audiochannels")
-                    self.txtChannels.setValue(int(c[0].childNodes[0].data))
-                    c = xmldoc.getElementsByTagName("audiochannellayout")
+                        # get the remaining values
+                        vf = xmldoc.getElementsByTagName("videoformat")
+                        self.txtVideoFormat.setText(vf[0].childNodes[0].data)
+                        vc = xmldoc.getElementsByTagName("videocodec")
+                        self.txtVideoCodec.setText(vc[0].childNodes[0].data)
+                        sr = xmldoc.getElementsByTagName("samplerate")
+                        self.txtSampleRate.setValue(int(sr[0].childNodes[0].data))
+                        c = xmldoc.getElementsByTagName("audiochannels")
+                        self.txtChannels.setValue(int(c[0].childNodes[0].data))
+                        c = xmldoc.getElementsByTagName("audiochannellayout")
 
-                    # check for compatible audio codec
-                    ac = xmldoc.getElementsByTagName("audiocodec")
-                    audio_codec_name = ac[0].childNodes[0].data
-                    if audio_codec_name == "aac":
-                        # Determine which version of AAC encoder is available
-                        if openshot.FFmpegWriter.IsValidCodec("libfaac"):
-                            self.txtAudioCodec.setText("libfaac")
-                        elif openshot.FFmpegWriter.IsValidCodec("libvo_aacenc"):
-                            self.txtAudioCodec.setText("libvo_aacenc")
-                        elif openshot.FFmpegWriter.IsValidCodec("aac"):
-                            self.txtAudioCodec.setText("aac")
+                        # check for compatible audio codec
+                        ac = xmldoc.getElementsByTagName("audiocodec")
+                        audio_codec_name = ac[0].childNodes[0].data
+                        if audio_codec_name == "aac":
+                            # Determine which version of AAC encoder is available
+                            if openshot.FFmpegWriter.IsValidCodec("libfaac"):
+                                self.txtAudioCodec.setText("libfaac")
+                            elif openshot.FFmpegWriter.IsValidCodec("libvo_aacenc"):
+                                self.txtAudioCodec.setText("libvo_aacenc")
+                            elif openshot.FFmpegWriter.IsValidCodec("aac"):
+                                self.txtAudioCodec.setText("aac")
+                            else:
+                                # fallback audio codec
+                                self.txtAudioCodec.setText("ac3")
                         else:
                             # fallback audio codec
-                            self.txtAudioCodec.setText("ac3")
-                    else:
-                        # fallback audio codec
-                        self.txtAudioCodec.setText(audio_codec_name)
+                            self.txtAudioCodec.setText(audio_codec_name)
 
-                    layout_index = 0
-                    for layout in self.channel_layout_choices:
-                        if layout == int(c[0].childNodes[0].data):
-                            self.cboChannelLayout.setCurrentIndex(layout_index)
-                            break
-                        layout_index += 1
+                        layout_index = 0
+                        for layout in self.channel_layout_choices:
+                            if layout == int(c[0].childNodes[0].data):
+                                self.cboChannelLayout.setCurrentIndex(layout_index)
+                                break
+                            layout_index += 1
 
             # init the profiles combo
             for item in sorted(profiles_list):
@@ -528,8 +542,11 @@ class Export(QDialog):
             if v_h or a_h:
                 self.cboSimpleQuality.addItem(_("High"), "High")
 
-            # Default to the highest quality setting
-            self.cboSimpleQuality.setCurrentIndex(previous_quality)
+            # Default to the highest quality setting (or previous quality setting)
+            if previous_quality <= self.cboSimpleQuality.count() - 1:
+                self.cboSimpleQuality.setCurrentIndex(previous_quality)
+            else:
+                self.cboSimpleQuality.setCurrentIndex(self.cboSimpleQuality.count() - 1)
 
     def cboSimpleVideoProfile_index_changed(self, widget, index):
         selected_profile_path = widget.itemData(index)
@@ -604,6 +621,14 @@ class Export(QDialog):
                     measurement = "mb"
                     bit_rate_bytes = raw_number * 1000.0 * 1000.0
 
+                elif "crf" in raw_measurement:
+                    measurement = "crf"
+                    if raw_number > 63:
+                        raw_number = 63
+                    if raw_number < 0:
+                        raw_number = 0
+                    bit_rate_bytes = raw_number
+
         except:
             pass
 
@@ -700,6 +725,18 @@ class Export(QDialog):
         export_cache_object = openshot.CacheMemory(250)
         self.timeline.SetCache(export_cache_object)
 
+        # Rescale all keyframes and reload project
+        if self.export_fps_factor != 1.0:
+            self.keyframes_rescaled = True
+            get_app().project.rescale_keyframes(self.export_fps_factor)
+
+            # Load the "export" Timeline reader with the JSON from the real timeline
+            json_timeline = json.dumps(get_app().project._data)
+            self.timeline.SetJson(json_timeline)
+
+            # Re-update the timeline FPS again (since the timeline just got clobbered)
+            self.updateFrameRate()
+
         # Create FFmpegWriter
         try:
             w = openshot.FFmpegWriter(export_file_path)
@@ -727,6 +764,16 @@ class Export(QDialog):
                                   audio_settings.get("channel_layout"),
                                   audio_settings.get("audio_bitrate"))
 
+            # Prepare the streams
+            w.PrepareStreams()
+
+            # These extra options should be set in an extra method
+            # No feedback is given to the user
+            # TODO: Tell user if option is not avaliable
+            # Set the quality in case crf was selected
+            if "crf" in self.txtVideoBitRate.text():
+                w.SetOption(openshot.VIDEO_STREAM, "crf", str(int(video_settings.get("video_bitrate"))) )
+
             # Open the writer
             w.Open()
 
@@ -813,9 +860,16 @@ class Export(QDialog):
 
         # Re-set OMP thread enabled flag
         if self.s.get("omp_threads_enabled"):
-            os.environ['OS2_OMP_THREADS'] = "1"
+            openshot.Settings.Instance().WAIT_FOR_VIDEO_PROCESSING_TASK = False
         else:
-            os.environ['OS2_OMP_THREADS'] = "0"
+            openshot.Settings.Instance().WAIT_FOR_VIDEO_PROCESSING_TASK = True
+
+        # Return scale mode to lower quality scaling (for faster previews)
+        openshot.Settings.Instance().HIGH_QUALITY_SCALING = False
+
+        # Return keyframes to preview scaling
+        if self.keyframes_rescaled:
+            get_app().project.rescale_keyframes(self.original_fps_factor)
 
         # Accept dialog
         super(Export, self).accept()
@@ -823,9 +877,16 @@ class Export(QDialog):
     def reject(self):
         # Re-set OMP thread enabled flag
         if self.s.get("omp_threads_enabled"):
-            os.environ['OS2_OMP_THREADS'] = "1"
+            openshot.Settings.Instance().WAIT_FOR_VIDEO_PROCESSING_TASK = False
         else:
-            os.environ['OS2_OMP_THREADS'] = "0"
+            openshot.Settings.Instance().WAIT_FOR_VIDEO_PROCESSING_TASK = True
+
+        # Return scale mode to lower quality scaling (for faster previews)
+        openshot.Settings.Instance().HIGH_QUALITY_SCALING = False
+
+        # Return keyframes to preview scaling
+        if self.keyframes_rescaled:
+            get_app().project.rescale_keyframes(self.original_fps_factor)
 
         # Cancel dialog
         self.exporting = False
